@@ -3,9 +3,8 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply chromatic and diatonic transposition to notes
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0103';
 
-use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
 use Music::Scales qw(get_scale_notes is_scale);
 use Music::Note;
@@ -67,7 +66,7 @@ sub transpose {
             push @transposed, $i == -1 ? undef : $self->_scale->[ $i + $offset ];
         }
     }
-    print 'Transposed: ', ddc(\@transposed) if $self->verbose;
+    print "Transposed: @transposed\n" if $self->verbose;
 
     return \@transposed;
 }
@@ -86,7 +85,7 @@ Music::MelodicDevice::Transposition - Apply chromatic and diatonic transposition
 
 =head1 VERSION
 
-version 0.0102
+version 0.0103
 
 =head1 SYNOPSIS
 
@@ -149,14 +148,13 @@ Create a new C<Music::MelodicDevice::Transposition> object.
 
   $transposed = $md->transpose($offset, $notes);
 
-Return the transposed series of notes.
+Return the transposed series of B<notes> given an B<offset>
+appropriately based on the number of notes in the chosen scale.
 
 =head1 SEE ALSO
 
 The F<t/01-methods.t> test file
 
-L<Data::Dumper::Compact>
-
 L<List::SomeUtils>
 
 L<Moo>
